#!/bin/sh
#
# Copyright (c) 2011-2012 EBM WebSourcing, 2012-2017 Linagora
#
# This program/library is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 2.1 of the License, or (at your
# option) any later version.
#
# This program/library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
# for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program/library; If not, see http://www.gnu.org/licenses/
# for the GNU Lesser General Public License version 2.1.
#
#############################################################################
#
#                      Petals ESB Bootstrap Script
#
# Environment variables:
#
#   JAVA_HOME           Directory containing the JRE. Use the java executable
#                       found in $PATH if not defined.
#
#   JAVA_OPTS           Options for the JVM. Try "java -h" to get informations
#                       about the available options for your environment
#
#   PETALS_CLASSPATH        Extra classpath entries for the system classloader.
#                       Careful because they will be visible by the whole JVM.
#
#############################################################################

# Extra checks
set -eu

# Let's get the distribution folder
PETALS_DIR="$(readlink -f "$(dirname "$(readlink -f "$0")")/../")"

# and execute all of this from it
cd "$PETALS_DIR"

# Set the path to the java executable
JAVA="${JAVA_HOME:-}/bin/java"
[ -x "$JAVA" ] || JAVA="$(which java)" || {
    echo "ERROR: java executable not found" >&2
    exit 1
}

PETALS_LIB_DIR="${PETALS_DIR}/lib"
PETALS_EXT_DIR="${PETALS_DIR}/extensions"
PETALS_CONF_DIR="${PETALS_DIR}/conf"
PETALS_LOG_DIR="${PETALS_DIR}/logs"
PETALS_SYSEXT_DIR="${PETALS_DIR}/system-extensions"

# Retrieve the path to petals bootstrap jar
PETALS_LAUNCHER_PATTERN="petals-launcher-default-*.jar"
# Careful, the pattern can't be inclosed inside quotes
PETALS_LAUNCHER_ARTIFACT="$(ls -1 "$PETALS_LIB_DIR/"$PETALS_LAUNCHER_PATTERN 2>/dev/null)"
# Check that the JAR is defined once
if [ -z "$PETALS_LAUNCHER_ARTIFACT" ]; then
   echo "ERROR: No Petals launcher found in directory $PETALS_LIB_DIR". Pattern was: $PETALS_LAUNCHER_PATTERN >&2
   exit 1
fi
# And only once!
if [ "$(echo "$PETALS_LAUNCHER_ARTIFACT" | wc -l)" -ne 1 ]; then
   echo -e "ERROR: Several Petals launcher versions were found in $PETALS_LIB_DIR:\n$PETALS_LAUNCHER_ARTIFACT" >&2
   exit 1
fi

# Classpath
PETALS_BOOTSTRAP_PATTERN="petals-bootstrap-launcher-*.jar"
# Careful, the pattern can't be inclosed inside quotes
PETALS_BOOTSTRAP_ARTIFACT="$(ls -1 "$PETALS_LIB_DIR/"$PETALS_BOOTSTRAP_PATTERN 2>/dev/null)"
# Check that the JAR is defined once
if [ -z "$PETALS_BOOTSTRAP_ARTIFACT" ]; then
   echo "ERROR: Petals Boostrap Launcher not found in $PETALS_LIB_DIR. Pattern was: $PETALS_BOOTSTRAP_PATTERN" >&2
   exit 1
fi;
# And only once!
if [ "$(echo "$PETALS_BOOTSTRAP_ARTIFACT" | wc -l)" -ne 1 ]; then
   echo -e "ERROR: Several Petals Bootstrap Launcher versions were found in $PETALS_LIB_DIR:\n$PETALS_BOOTSTRAP_ARTIFACT" >&2
   exit 1
fi

# Add the conf directory to the classpath to provide the default server configuration
# Add the extra system libs dir as well as any extra command line classpath elements
PETALS_CLASSPATH="$PETALS_BOOTSTRAP_ARTIFACT:$PETALS_CONF_DIR:$PETALS_SYSEXT_DIR:${PETALS_CLASSPATH:-}"

# Adapt pathes if architecture is Cygwin (unix if read by the command line and dos if read by java)
case "`uname`" in
    CYGWIN*)
        JAVA="$(cygpath --unix "$JAVA")"
        PETALS_LAUNCHER_ARTIFACT="$(cygpath --windows "$PETALS_LAUNCHER_ARTIFACT")"
        PETALS_LIB_DIR="$(cygpath --dos "$PETALS_LIB_DIR")"
        PETALS_EXT_DIR="$(cygpath --dos "$PETALS_EXT_DIR")"
        PETALS_CLASSPATH="$(cygpath --path --windows "$PETALS_CLASSPATH")"
        ;;
esac

# let's remember the current value if it's set, we will put it AFTER the one from env.sh
# to have the original one override it.
ORIGINAL_JAVA_OPTS=${JAVA_OPTS:-}

# set JAVA_OPTS for env.sh to have a value because we are in strict mode
JAVA_OPTS=""
PETALS_STOP_ASKED="false"
`echo "$@" | grep -qE "stop$"` && {
    PETALS_STOP_ASKED="true"
}

ENV_FILE="${PETALS_CONF_DIR}/env.sh"
if [ -f "$ENV_FILE" ]; then
    . "$ENV_FILE"
fi

# Start
exec "$JAVA" \
    -classpath "$PETALS_CLASSPATH" \
    -Dpetals.lib.dir="$PETALS_LIB_DIR" \
    -Dpetals.ext.dir="$PETALS_EXT_DIR" \
    -Dpetals.log.dir="$PETALS_LOG_DIR" \
    $JAVA_OPTS \
    $ORIGINAL_JAVA_OPTS \
    org.ow2.petals.BootstrapLauncher \
    "$PETALS_LAUNCHER_ARTIFACT" \
    "$@"
